==> haskell-x509-validation-1.6.11-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.11
id: x509-validation-1.6.11-B4XHiOnvZY59GNnl3eOH5e
key: x509-validation-1.6.11-B4XHiOnvZY59GNnl3eOH5e
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation. please see README
category: Data
abi: 21f9b55829e1a1b65428ba4b4bbdd70b
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-validation-1.6.11
hs-libraries: HSx509-validation-1.6.11-B4XHiOnvZY59GNnl3eOH5e
depends:
    asn1-encoding-0.9.5-6xTC56rlj2161Wc0QnpN3c
    asn1-types-0.3.2-C4CHpadXLTCBj8vIRwXTVq base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hourglass-0.2.12-JEaEpOfLV0DFo2lqKaBxXr
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6 mtl-2.2.2
    pem-0.2.4-ELi0swn78WkIfsL2hxjv1i x509-1.7.5-4SipZUEfLKoGzZKIMuaQ6w
    x509-store-1.6.7-KIqe5sij70W6buPBlQvxx7
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.11-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.11
id: x509-validation-1.6.11-9VzJSwXVI2q4MJDcevqYRy
key: x509-validation-1.6.11-9VzJSwXVI2q4MJDcevqYRy
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation. please see README
category: Data
abi: 9846fe5024e361616a828c80811decad
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-validation-1.6.11
hs-libraries: HSx509-validation-1.6.11-9VzJSwXVI2q4MJDcevqYRy
depends:
    asn1-encoding-0.9.5-FtBwZmITEqjG5wmLP5aEcM
    asn1-types-0.3.2-4cCwnYpGwdvAcPUkJr4Peh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hourglass-0.2.12-fB7MRhZDyAiIoU3zde7Y
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6 mtl-2.2.2
    pem-0.2.4-99TOG2Rr4w4I5rsziTr4zP x509-1.7.5-2aJTIlmfgWy7rdDeXhQjzU
    x509-store-1.6.7-EwWb1eePfQxDIqP8dSgvwf
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
